require 'uu/os/gvc/component'

module UU
  module OS
    module GVC

      # Link component.
      class Link < UU::OS::GVC::Component

        # Defines target window where the action URI will be opened - one of "CURRENT_WINDOW" (default),
        # "NEW_WINDOW", "DIALOG_WINDOW". For backward compatibility it's also possible to use older equivalents
        # "SELF", "NEW" and "MODAL".
        attr_accessor :target

        # Flag if component is disabled.
        attr_accessor :disabled

        # Link text.
        attr_accessor :text

        # Link tooltip text.
        attr_accessor :tooltip

        # Link uri. Can contain valid UESURI or uri to external web page. Web page uris must
        # have one of supported schemas (http, https). External web pages are always opened into
        # new window (attribute target is ignored).
        attr_accessor :action_uri

        # The style for the component. The value can be semicolon separated String
        # containing style rules or a Hash. The style has bigger priority than
        # styling via style_class. Allowed styles:
        #
        # * color, background-color - the color of the link text / background as a hexa value, e.g. '#123456'.
        # * font-family, font-size, font-style, font-weight - font styling (see CSS for possible values)
        # * text-decoration - underline / strike-through decorations (see CSS for possible values)
        #
        # @return The style for the component. Due to backward compatibility,
        #         the return value is the same as the one used for setting the value.
        # @example
        #   link.style = { :color => '#123456' }
        #   a = link.style                       # returns { :color => '#123456' }
        #
        #   link.style = 'font-style: italic; font-weight: bold; font-size: 15px;'
        #   b = link.style                       # returns 'font-style: italic; font-weight: bold; font-size: 15px;'
        attr_accessor :style

        # Flag if link can show system tooltip
        attr_accessor :system_tooltip

        # Flag if link can show system icons
        attr_accessor :system_icon

        def target
          attributes[:target]
        end

        def target=(target)
          attributes[:target] = target
        end

        def disabled
          attributes[:disabled]
        end

        def disabled=(disabled)
          attributes[:disabled] = disabled
        end

        def text
          attributes[:text]
        end

        def text=(text)
          attributes[:text] = text
        end

        def tooltip
          attributes[:tooltip]
        end

        def tooltip=(tooltip)
          attributes[:tooltip] = tooltip
        end

        def action_uri
          attributes[:actionUri]
        end

        def action_uri=(action_uri)
          attributes[:actionUri] = action_uri
        end

        def style
          attributes[:style]
        end

        def style=(style)
          attributes[:style] = style
        end

        def system_tooltip
            attributes[:systemTooltip]
        end

        def system_tooltip=(system_tooltip)
          attributes[:systemTooltip] = system_tooltip
        end

        def system_icon
          attributes[:systemIcon]
        end

        def system_icon=(system_icon)
          attributes[:systemIcon] = system_icon
        end

      end
    end
  end
end
